==> unify_api-1.0.4.tar.gz: lib/unify.dart <==
library unify;

import 'dart:async';

import 'package:meta/meta.dart';
import 'dart:io';

import 'src/impl/unsupported.dart'
    if (dart.library.html) 'src/impl/browser.dart'
    if (dart.library.io) 'src/impl/io.dart';

part 'src/client.dart';
part 'src/endpoints.dart';
part 'src/token.dart';
part 'src/types/object.dart';
part 'src/types/account/details.dart';
part 'src/types/common/phone_number.dart';
part 'src/types/common/postal_address.dart';
part 'src/types/contacts/note.dart';
part 'src/types/leads/note.dart';
part 'src/types/common/tracker.dart';
part 'src/types/common/task.dart';
part 'src/types/common/local_data.dart';
part 'src/types/common/alert.dart';
part 'src/types/contacts/list.dart';
part 'src/types/contacts/details.dart';
part 'src/types/contacts/company_category.dart';
part 'src/types/contacts/contact_group.dart';
part 'src/types/contacts/loan_history.dart';
part 'src/types/leads/list.dart';
part 'src/types/leads/details.dart';
part 'src/types/leads/lead_group.dart';
part 'src/types/dashboard/list.dart';
part 'src/types/dashboard/stats.dart';
part 'src/types/dashboard/partners.dart';
part 'src/types/loans/details.dart';
part 'src/types/loans/list.dart';
part 'src/types/loans/progress.dart';
part 'src/types/loans/contact.dart';
part 'src/types/core_leads/list.dart';
part 'src/types/core_leads/details.dart';
part 'src/types/videos/list.dart';
part 'src/types/videos/details.dart';
part 'src/types/marketing/section.dart';
part 'src/types/marketing/material.dart';
part 'src/types/marketing/details.dart';
part 'src/types/marketing/list.dart';
part 'src/types/marketing/partners.dart';
part 'src/types/marketing/validation.dart';
part 'src/types/cart/list.dart';
part 'src/types/cart/order.dart';

==> unify_api-1.1.3.tar.gz: lib/unify.dart <==
library unify;

import 'dart:async';

import 'package:meta/meta.dart';

// import 'src/impl/unsupported.dart'
//     if (dart.library.html) 'src/impl/browser.dart'
//     if (dart.library.io) 'src/impl/io.dart';

// import 'src/impl/unsupported.dart'
//     if (dart.library.html) 'src/impl/browser.dart'
//     if (dart.library.io) 'src/impl/mobile.dart';

import 'src/impl/mobile.dart';


part 'src/client.dart';
part 'src/endpoints.dart';
part 'src/token.dart';
part 'src/types/account/details.dart';
part 'src/types/account/stats.dart';
part 'src/types/cart/list.dart';
part 'src/types/cart/order.dart';
part 'src/types/common/alert.dart';
part 'src/types/common/local_data.dart';
part 'src/types/common/phone_number.dart';
part 'src/types/common/postal_address.dart';
part 'src/types/common/task.dart';
part 'src/types/common/tracker.dart';
part 'src/types/contacts/company_category.dart';
part 'src/types/contacts/contact_group.dart';
part 'src/types/contacts/details.dart';
part 'src/types/contacts/list.dart';
part 'src/types/contacts/loan_history.dart';
part 'src/types/contacts/note.dart';
part 'src/types/core_leads/details.dart';
part 'src/types/core_leads/list.dart';
part 'src/types/dashboard/list.dart';
part 'src/types/dashboard/partners.dart';
part 'src/types/dashboard/stats.dart';
part 'src/types/leads/details.dart';
part 'src/types/leads/lead_group.dart';
part 'src/types/leads/list.dart';
part 'src/types/leads/note.dart';
part 'src/types/loans/contact.dart';
part 'src/types/loans/details.dart';
part 'src/types/loans/list.dart';
part 'src/types/loans/progress.dart';
part 'src/types/marketing/details.dart';
part 'src/types/marketing/list.dart';
part 'src/types/marketing/material.dart';
part 'src/types/marketing/partners.dart';
part 'src/types/marketing/section.dart';
part 'src/types/marketing/validation.dart';
part 'src/types/object.dart';
part 'src/types/videos/details.dart';
part 'src/types/videos/list.dart';
